print("import: 'requests_toolbelt'")
import requests_toolbelt

print("import: 'requests_toolbelt.adapters'")
import requests_toolbelt.adapters

print("import: 'requests_toolbelt.auth'")
import requests_toolbelt.auth

print("import: 'requests_toolbelt.downloadutils'")
import requests_toolbelt.downloadutils

print("import: 'requests_toolbelt.multipart'")
import requests_toolbelt.multipart

print("import: 'requests_toolbelt.threaded'")
import requests_toolbelt.threaded

print("import: 'requests_toolbelt.utils'")
import requests_toolbelt.utils

